@@ -39,10 +39,5 @@ PositionDodge <- proto(Position, {
     collide(data, .$width, .$my_name(), pos_dodge, check.width = FALSE)
   }  
 
-  icon <- function(.) {
-    y <- c(0.5, 0.3)
-    rectGrob(c(0.25, 0.75), y, width=0.4, height=y, gp=gpar(col="grey60", fill=c("#804070", "#668040")), vjust=1)
-  }
-
 })
 
