@@ -1,5 +1,8 @@
 #' Calculate contours of 3d data.
 #' 
+#' @section Aesthetics: 
+#' \Sexpr[results=rd,stage=build]{ggplot2:::rd_aesthetics("stat", "contour")}
+#'
 #' @inheritParams stat_identity
 #' @param na.rm If \code{FALSE} (the default), removes missing values with
 #'    a warning.  If \code{TRUE} silently removes missing values.
@@ -58,7 +61,7 @@ na.rm = FALSE, ...) {
 StatContour <- proto(Stat, {
   objname <- "contour"
 
-  calculate <- function(., data, scales, bins=NULL, binwidth=NULL, breaks = NULL, na.rm = FALSE, ...) {
+  calculate <- function(., data, scales, bins=NULL, binwidth=NULL, breaks = NULL, complete = FALSE, na.rm = FALSE, ...) {
     data <- remove_missing(data, na.rm, name = "stat_contour", finite = TRUE)
 
     # If no parameters set, use pretty bins
@@ -74,27 +77,65 @@ StatContour <- proto(Stat, {
       breaks <- fullseq(range(data$z), binwidth)
     }
     
-    z <- tapply(data$z, data[c("x", "y")], identity)
-    cl <- contourLines(
-      x = sort(unique(data$x)), y = sort(unique(data$y)), z = z, 
-      levels = breaks)  
-    if (length(cl) == 0) {
-      warning("Not possible to generate contour data", call. = FALSE)
-      return(data.frame())
-    }
-
-    cl <- lapply(cl, as.data.frame)    
-    contour_df <- rbind.fill(cl)
-    contour_df$piece <- rep(seq_along(cl), sapply(cl, nrow))
-    contour_df$group <- paste(data$group[1], contour_df$piece, sep = "-")
-    contour_df
+    contour_lines(data, breaks, complete = complete)
   }
 
   
-  icon <- function(.) GeomContour$icon()
-  
   default_geom <- function(.) GeomPath
   default_aes <- function(.) aes(order = ..level..)
   required_aes <- c("x", "y", "z")
 })
 
+
+# v3d <- reshape2::melt(volcano)
+# names(v3d) <- c("x", "y", "z")
+#
+# breaks <- seq(95, 195, length = 10)
+# contours <- contour_lines(v3d, breaks)
+# qplot(x, y, data = contours, geom = "path") + facet_wrap(~ piece)
+contour_lines <- function(data, breaks, complete = FALSE) {
+  z <- tapply(data$z, data[c("x", "y")], identity)
+
+  cl <- contourLines(
+    x = sort(unique(data$x)), y = sort(unique(data$y)), z = z, 
+    levels = breaks)  
+
+  if (length(cl) == 0) {
+    warning("Not possible to generate contour data", call. = FALSE)
+    return(data.frame())
+  }
+
+  # Convert list of lists into single data frame
+  lengths <- vapply(cl, function(x) length(x$x), integer(1))
+  levels <- vapply(cl, "[[", "level", FUN.VALUE = double(1))
+  xs <- unlist(lapply(cl, "[[", "x"), use.names = FALSE)
+  ys <- unlist(lapply(cl, "[[", "y"), use.names = FALSE)
+  pieces <- rep(seq_along(cl), lengths)
+  
+  data.frame(
+    level = rep(levels, lengths),
+    x = xs,
+    y = ys,
+    piece = pieces,
+    group = paste(data$group[1], pieces, sep = "-")
+  )
+}
+
+# 1 = clockwise, -1 = counterclockwise, 0 = 0 area
+# From http://stackoverflow.com/questions/1165647
+# x <- c(5, 6, 4, 1, 1)
+# y <- c(0, 4, 5, 5, 0)
+# poly_dir(x, y)
+poly_dir <- function(x, y) {
+  xdiff <- c(x[-1], x[1]) - x
+  ysum <- c(y[-1], y[1]) + y
+  sign(sum(xdiff * ysum))
+}
+
+# To fix breaks and complete the polygons, we need to add 0-4 corner points.
+#
+# contours <- ddply(contours, "piece", mutate, dir = poly_dir(x, y))
+# qplot(x, y, data = contours, geom = "path", group = piece, 
+#   colour = factor(dir))
+# last_plot() + facet_wrap(~ level)
+
