@@ -63,7 +63,7 @@ StatSum <- proto(Stat, {
     group_by <- setdiff(intersect(names(data), .all_aesthetics), "weight")
 
     counts <- count(data, group_by, wt_var = "weight")
-    counts <- rename(counts, c(freq = "n"))
+    counts <- rename(counts, c(freq = "n"), warn_missing = FALSE)
     counts$prop <- ave(counts$n, counts$group, FUN = prop.table)
     counts
   }
