@@ -24,7 +24,7 @@
 #' p + geom_line(aes(colour=mpg)) 
 #' }
 ggpcp <- function(data, vars=names(data), ...) {
-  .Deprecated()
+  gg_dep("0.9.1", "ggpcp is deprecated.")
   scaled <- as.data.frame(lapply(data[, vars], rescale01))
   data <- cunion(scaled, data)
   
@@ -60,7 +60,7 @@ ggpcp <- function(data, vars=names(data), ...) {
 #' ggfluctuation(table(warpbreaks$breaks, warpbreaks$tension))
 #' }
 ggfluctuation <- function(table, type="size", floor=0, ceiling=max(table$freq, na.rm=TRUE)) {
-  .Deprecated()
+  gg_dep("0.9.1", "ggfluctuation is deprecated.")
   if (is.table(table)) table <- as.data.frame(t(table))
   
   oldnames <- names(table)
@@ -130,7 +130,7 @@ ggfluctuation <- function(table, type="size", floor=0, ceiling=max(table$freq, n
 #' ggmissing(mmissing, avoid="dodge") + scale_y_sqrt()
 #' }
 ggmissing <- function(data, avoid="stack", order=TRUE, missing.only = TRUE) {
-  .Deprecated()
+  gg_dep("0.9.1", "ggmissing is deprecated.")
   missings <- mapply(function(var, name) cbind(as.data.frame(table(missing=factor(is.na(var), levels=c(TRUE, FALSE), labels=c("yes", "no")))), variable=name), 
     data, names(data), SIMPLIFY=FALSE
   )
@@ -162,7 +162,7 @@ ggmissing <- function(data, avoid="stack", order=TRUE, missing.only = TRUE) {
 #' ggstructure(mtcars)
 #' }
 ggstructure <- function(data) {
-  .Deprecated()
+  gg_dep("0.9.1", "ggstructure is deprecated.")
   ggpcp(data) + 
     aes_string(y="ROWID", fill="value", x="variable") +
     geom_tile() +
@@ -175,7 +175,7 @@ ggstructure <- function(data) {
 #' @param data data set to plot
 #' @export
 ggorder <- function(data) {
-  .Deprecated()
+  gg_dep("0.9.1", "ggorder is deprecated.")
   ggpcp(data) +
     aes_string(x="ROWID", group="variable", y="value") +
     facet_grid(. ~ variable) +
@@ -185,7 +185,7 @@ ggorder <- function(data) {
 
 # Distribution plot.
 ggdist <- function(data, vars=names(data), facets = . ~ .) {
-  .Deprecated()
+  gg_dep("0.9.1", "ggdist is deprecated.")
   cat <- sapply(data[vars], is.factor)
   facets <- deparse(substitute(facets))
   
