@@ -81,3 +81,36 @@ theme_bw <- function(base_size = 12, base_family = "") {
       strip.background  = element_rect(fill = "grey80", colour = "grey50")
     )
 }
+
+#' A minimalistic theme with no background annotations.
+#'
+#' @param base_size base font size
+#' @param base_family base font family
+#' @export
+theme_minimal <- function(base_size = 12, base_family = "") {
+  # Starts with theme_bw and then modify some parts
+  theme_bw(base_size = base_size, base_family = base_family) %+replace%
+    theme(
+      legend.background = element_blank(),
+      legend.key        = element_blank(),
+      panel.background  = element_blank(),
+      panel.border      = element_blank(),
+      strip.background  = element_blank(),
+      plot.background   = element_blank()
+    )
+}
+
+#' A classic-looking theme, with x and y axis lines and no gridlines.
+#'
+#' @param base_size base font size
+#' @param base_family base font family
+#' @export
+theme_classic <- function(base_size = 12, base_family = ""){
+  theme_bw(base_size = base_size, base_family = base_family) %+replace%
+    theme(
+      panel.border     = element_blank(),
+      axis.line        = element_line(colour = "black"),
+      panel.grid.major = element_blank(),
+      panel.grid.minor = element_blank()
+    )
+}
